@@ -19,8 +19,7 @@ import gc
 import logging
 import sys
 
-import lib.gichecks
-from gi.repository import GdkPixbuf
+from lib.gibindings import GdkPixbuf
 from lib.gettext import C_
 
 from . import mypaintlib
@@ -547,6 +546,11 @@ def record_memory_leak_status(print_diff=False):
     old_stats = new_stats
 
 
+def utf8(string):
+    """Return the input as bytes encoded by utf-8"""
+    return string.encode('utf-8')
+
+
 def fmt_time_period_abbr(t):
     """Get a localized abbreviated minutes+seconds string
 
